# -*- coding: utf-8 -*-

class KubernetesObjectTypeEnum(object):

    """Implementation of the 'kubernetesObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KCLUSTER: TODO: type description here.
        KNAMESPACE: TODO: type description here.
        KSERVICE: TODO: type description here.
        KPVC: TODO: type description here.
        KLABEL: TODO: type description here.

    """

    KCLUSTER = 'kCluster'

    KNAMESPACE = 'kNamespace'

    KSERVICE = 'kService'

    KPVC = 'kPVC'

    KLABEL = 'kLabel'
